==> live-normal-service-api-0.4.9-20220418.064131-9-sources.jar: cn/com/duiba/live/normal/service/api/dto/oto/cust/CustCallRecordDto.java <==
package cn.com.duiba.live.normal.service.api.dto.oto.cust;

import lombok.Data;

import java.io.Serializable;

/**
 * 客户通话表单记录表
 * @author kjj mybatis generator 
 * @date 2022-01-12
 */
@Data
public class CustCallRecordDto implements Serializable {
     
    private static final long serialVersionUID = 16419780996007343L;

    /**
     * 主键id
     */
    private Long id;

    /**
     * 销售id, tb_oto_seller.id
     */
    private Long sellerId;

    /**
     * 客户id, tb_oto_customer.id
     */
    private Long custId;

    /**
     * 通话记录日志id tb_cust_log_id
     */
    private Long callLogId;

    /**
     * 客户价值  1XX代表未接通 2XX中XX代表分数 3XX代表系统高价值
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.ext.OtoCustValueEnum
     */
    private Integer custValue;

    /**
     * 核心决策人 0:不明或其他 1:本人或配偶 2:子女 3：父母
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.ext.OtoCustCoreMakerEnum
     */
    private Integer coreMaker;

    /**
     * 标签id，用，隔开
     */
    private String tagIds;

    /**
     * 提交计划书后客户状态 1近期有机会成交 2近期无法成交 3拒绝
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.visit.OtoCustCommitStatusEnum
     */
    private Integer commitCustStatus;

    /**
     * 是否提交养老规划方案 0否 1是
     * @see cn.com.duiba.live.normal.service.api.enums.BooleanEnum
     */
    private Integer commitPlanFlag;

    /**
     * 客户备注
     */
    private String custDescription;

    /**
     * 跟进客户权重
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.follow.OtoCustFollowWeightEnum
     */
    private Integer followWeight;

    /**
     * 销售评价类型
     * @see cn.com.duiba.live.normal.service.api.enums.oto.OtoCommentTypeEnum
     */
    private Integer commentType;

    /**
     * 评价备注
     * @see cn.com.duiba.live.normal.service.api.enums.oto.log.CustCommonLogKeyEnum
     */
    private String commentRemark;
}

==> live-normal-service-api-0.4.29-20220602.033213-26-sources.jar: cn/com/duiba/live/normal/service/api/dto/oto/cust/CustCallRecordDto.java <==
package cn.com.duiba.live.normal.service.api.dto.oto.cust;

import cn.com.duiba.live.normal.service.api.enums.oto.cust.CustGenderEnum;
import cn.com.duiba.live.normal.service.api.enums.oto.cust.call.OtoCustomerCallEndTypeEnum;
import cn.com.duiba.live.normal.service.api.enums.oto.cust.call.OtoCustomerCallSubmittedEnum;
import java.util.Date;
import lombok.Data;

import java.io.Serializable;

/**
 * 客户通话表单记录表
 * @author kjj mybatis generator 
 * @date 2022-01-12
 */
@Data
public class CustCallRecordDto implements Serializable {
     
    private static final long serialVersionUID = 16419780996007343L;

    /**
     * 主键id
     */
    private Long id;

    /**
     * 销售id, tb_oto_seller.id
     */
    private Long sellerId;

    /**
     * 客户id, tb_oto_customer.id
     */
    private Long custId;

    /**
     * 通话记录日志id tb_cust_log_id
     */
    private Long callLogId;

    /**
     * 客户价值  1XX代表未接通 2XX中XX代表分数 3XX代表系统高价值
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.ext.OtoCustValueEnum
     */
    private Integer custValue;

    /**
     * 核心决策人 0:不明或其他 1:本人或配偶 2:子女 3：父母
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.ext.OtoCustCoreMakerEnum
     */
    private Integer coreMaker;

    /**
     * 标签id，用，隔开
     */
    private String tagIds;

    /**
     * 提交方案后客户状态 1近期有机会成交 2近期无法成交 3拒绝
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.visit.OtoCustCommitStatusEnum
     */
    private Integer commitCustStatus;

    /**
     * 是否提交养老规划方案 0否 1是
     * @see cn.com.duiba.live.normal.service.api.enums.BooleanEnum
     */
    private Integer commitPlanFlag;

    /**
     * 客户备注
     */
    private String custDescription;

    /**
     * 跟进客户权重
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.follow.OtoCustFollowWeightEnum
     */
    private Integer followWeight;

    /**
     * 销售评价类型
     * @see cn.com.duiba.live.normal.service.api.enums.oto.OtoCommentTypeEnum
     */
    private Integer commentType;

    /**
     * 评价备注
     * @see cn.com.duiba.live.normal.service.api.enums.oto.log.CustCommonLogKeyEnum
     */
    private String commentRemark;

    /**
     * 居住地址
     */
    private String custAddress;

    /**
     * 客户性别
     * @see CustGenderEnum
     */
    private Integer custGender;

    /**
     * 客户姓名
     */
    private String custName;

    /**
     * 退休金
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.ext.OtoCustRetireMoneyEnum
     */
    private Integer retireMoney;

    /**
     * 年龄
     */
    private Integer age;

    /**
     * 通话结束类型
     * @see OtoCustomerCallEndTypeEnum
     */
    private Integer callEndType;

    /**
     * 通话结束时间
     */
    private Date callEndTime;

    /**
     * 是否客户以提交表单
     * @see OtoCustomerCallSubmittedEnum
     */
    private Integer submitFlag;

    /**
     * 考虑原因
     * @see cn.com.duiba.live.normal.service.api.enums.oto.cust.ext.OtoCustReasonEnum
     */
    private Integer considerReason;

    /**
     * 通话开始时间
     */
    private Date gmtCreate;

}
